# is_single_rgb()

## How to use

1. ```python
   from colorcodetools.rgb.validate import is_single_rgb
   is_single_rgb(r/g/b)
   ```
2. ```python
   import colorcodetools
   colorcodetools.rgb.validate.is_single_rgb(r/g/b)
   ```

## Parameters

1. Required parameters:

   - rgb:  
      Enter a single rgb code part.
     - `type: int`
     - `default: None`
     - `example: 255`

## Return value

- `type: boolean`
